pub struct GetQueryResultsResponse {
pub kind: String,
pub etag: String,
pub schema: Option<TableSchema>,
pub job_reference: JobReference,
pub total_rows: i64,
pub page_token: Option<String>,
pub rows: Option<Vec<Tuple>>,
pub total_bytes_processed: Option<i64>,
pub job_complete: bool,
pub errors: Option<Vec<ErrorProto>>,
pub cache_hit: Option<bool>,
pub num_dml_affected_rows: Option<i64>,
}Fields
kind: StringThe resource type.
etag: StringA hash of this response.
schema: Option<TableSchema>The schema of the results. Present only when the query completes successfully.
job_reference: JobReferenceReference to the Job that was created to run the query. This field will be present even if the original request timed out, in which case jobs.getQueryResults can be used to read the results once the query has completed. Since this API only returns the first page of results, subsequent pages can be fetched via the same mechanism (jobs.getQueryResults).
total_rows: i64The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results.
page_token: Option<String>A token used for paging results. A non-empty token indicates that additional results are available. To see additional results, query the jobs.getQueryResults method. For more information, see Paging through table data.
rows: Option<Vec<Tuple>>An object with as many results as can be contained within the maximum permitted reply size. To get any additional rows, you can call jobs.getQueryResults and specify the jobReference returned above.
total_bytes_processed: Option<i64>The total number of bytes processed for this query. If this query was a dry run, this is the number of bytes that would be processed if the query were run.
job_complete: boolWhether the query has completed or not. If rows or totalRows are present, this will always be true. If this is false, totalRows will not be available.
errors: Option<Vec<ErrorProto>>Output only. The first errors or warnings encountered during the running of the job. The final message includes the number of errors that caused the process to stop. Errors here do not necessarily mean that the job has completed or was unsuccessful. For more information about error messages, see Error messages.
cache_hit: Option<bool>Whether the query result was fetched from the query cache.
num_dml_affected_rows: Option<i64>Output only. The number of rows affected by a DML statement. Present only for DML statements INSERT, UPDATE or DELETE.