Modules
Structs
- Blocking
Retry - Retry structure generated by
BlockingRetryable. - Blocking
Retry With Context - Retry structure generated by
BlockingRetryableWithContext. - Constant
Builder - ConstantBuilder is used to create a [
ConstantBackoff], providing a steady delay with a fixed number of retries. - Exponential
Builder - ExponentialBuilder is used to construct an [
ExponentialBackoff] that offers delays with exponential retries. - Fibonacci
Builder - FibonacciBuilder is used to build a [
FibonacciBackoff] which offers a delay with Fibonacci-based retries. - Iterator
- Query
Option - Retry
- Struct generated by
Retryable. - Retry
With Context - Retry struct generated by
RetryableWithContext. - Tokio
Sleeper - The default implementation of
Sleeperusestokio::time::sleep.
Enums
Traits
- Backoff
- Backoff is an
Iteratorthat returnsDuration. - Backoff
Builder - BackoffBuilder is utilized to construct a new backoff.
- Blocking
Retryable - BlockingRetryable adds retry support for blocking functions.
- Blocking
Retryable With Context - BlockingRetryableWithContext adds retry support for blocking functions.
- Blocking
Sleeper - A sleeper is used sleep for a specified duration.
- Retryable
- Retryable will add retry support for functions that produce futures with results.
- Retryable
With Context RetryableWithContextadds retry support for functions that produce futures with results and context.- Sleeper
- A sleeper is used to generate a future that completes after a specified duration.
Type Aliases
- Default
Blocking Sleeper - The default implementation of
Sleeperwhen no features are enabled. - Default
Sleeper - The default implementation of
Sleeperwhile featuretokio-sleepenabled.