pub struct FixedLexicographicalComparator<const N: usize> { /* private fields */ }Expand description
A lexicographical comparator that wraps given array data (columns) and can lexicographically compare data at given two indices. This version of the comparator is for compile-time constant number of columns. The lifetime is the same at the data wrapped.
Implementations
Sourceimpl<const N: usize> FixedLexicographicalComparator<N>
impl<const N: usize> FixedLexicographicalComparator<N>
Sourcepub fn compare(&self, a_idx: usize, b_idx: usize) -> Ordering
pub fn compare(&self, a_idx: usize, b_idx: usize) -> Ordering
lexicographically compare values at the wrapped columns with given indices.
Sourcepub fn try_new(
columns: &[SortColumn],
) -> Result<FixedLexicographicalComparator<N>, ArrowError>
pub fn try_new( columns: &[SortColumn], ) -> Result<FixedLexicographicalComparator<N>, ArrowError>
Create a new lex comparator that will wrap the given sort columns and give comparison results with two indices. The number of columns should be equal to the compile-time constant N.