pub struct FileReader<R> { /* private fields */ }Expand description
Arrow File Reader
Reads Arrow RecordBatches from bytes in the IPC File Format,
providing random access to the record batches.
See Also
Self::set_indexfor random accessStreamReaderfor reading streaming data
Example: Reading from a File
use arrow_array::record_batch;
let projection = None; // read all columns
let mut reader = FileReader::try_new(&mut file, projection).unwrap();
// Position the reader to the second batch
reader.set_index(1).unwrap();
// read batches from the reader using the Iterator trait
let mut num_rows = 0;
for batch in reader {
let batch = batch.unwrap();
num_rows += batch.num_rows();
}
assert_eq!(num_rows, 3);Example: Reading from mmaped file
For an example creating Arrays without copying using memory mapped (mmap)
files see the zero_copy_ipc example.
Implementations
Sourceimpl<R> FileReader<BufReader<R>>
impl<R> FileReader<BufReader<R>>
Sourcepub fn try_new_buffered(
reader: R,
projection: Option<Vec<usize>>,
) -> Result<FileReader<BufReader<R>>, ArrowError>
pub fn try_new_buffered( reader: R, projection: Option<Vec<usize>>, ) -> Result<FileReader<BufReader<R>>, ArrowError>
Try to create a new file reader with the reader wrapped in a BufReader.
See FileReader::try_new for an unbuffered version.
Sourceimpl<R> FileReader<R>
impl<R> FileReader<R>
Sourcepub fn try_new(
reader: R,
projection: Option<Vec<usize>>,
) -> Result<FileReader<R>, ArrowError>
pub fn try_new( reader: R, projection: Option<Vec<usize>>, ) -> Result<FileReader<R>, ArrowError>
Try to create a new file reader.
There is no internal buffering. If buffered reads are needed you likely want to use
FileReader::try_new_buffered instead.
Errors
An ‘Err’ may be returned if:
- the file does not meet the Arrow Format footer requirements, or
- file endianness does not match the target endianness.
Sourcepub fn custom_metadata(&self) -> &HashMap<String, String>
pub fn custom_metadata(&self) -> &HashMap<String, String>
Return user defined customized metadata
Sourcepub fn num_batches(&self) -> usize
pub fn num_batches(&self) -> usize
Return the number of batches in the file
Sourcepub fn set_index(&mut self, index: usize) -> Result<(), ArrowError>
pub fn set_index(&mut self, index: usize) -> Result<(), ArrowError>
See to a specific RecordBatch
Sets the current block to the index, allowing random reads
Sourcepub fn get_ref(&self) -> &R
pub fn get_ref(&self) -> &R
Gets a reference to the underlying reader.
It is inadvisable to directly read from the underlying reader.
Sourcepub fn get_mut(&mut self) -> &mut R
pub fn get_mut(&mut self) -> &mut R
Gets a mutable reference to the underlying reader.
It is inadvisable to directly read from the underlying reader.
Sourcepub unsafe fn with_skip_validation(self, skip_validation: bool) -> FileReader<R> ⓘ
pub unsafe fn with_skip_validation(self, skip_validation: bool) -> FileReader<R> ⓘ
Specifies if validation should be skipped when reading data (defaults to false)
Safety