CompressionContext

Struct CompressionContext 

pub struct CompressionContext {}
Additional context that may be needed for compression.

In the case of zstd, this will contain the zstd context, which can be reused between subsequent compression calls to avoid the performance overhead of initialising a new context for every compression.