Module query

Module query 

Modules

row
run

Structs

BlockingRetry
Retry structure generated by BlockingRetryable.
BlockingRetryWithContext
Retry structure generated by BlockingRetryableWithContext.
ConstantBuilder
ConstantBuilder is used to create a [ConstantBackoff], providing a steady delay with a fixed number of retries.
ExponentialBuilder
ExponentialBuilder is used to construct an [ExponentialBackoff] that offers delays with exponential retries.
FibonacciBuilder
FibonacciBuilder is used to build a [FibonacciBackoff] which offers a delay with Fibonacci-based retries.
Iterator
QueryOption
Retry
Struct generated by Retryable.
RetryWithContext
Retry struct generated by RetryableWithContext.
TokioSleeper
The default implementation of Sleeper uses tokio::time::sleep.

Enums

Error
QueryResult

Traits

Backoff
Backoff is an Iterator that returns Duration.
BackoffBuilder
BackoffBuilder is utilized to construct a new backoff.
BlockingRetryable
BlockingRetryable adds retry support for blocking functions.
BlockingRetryableWithContext
BlockingRetryableWithContext adds retry support for blocking functions.
BlockingSleeper
A sleeper is used sleep for a specified duration.
Retryable
Retryable will add retry support for functions that produce futures with results.
RetryableWithContext
RetryableWithContext adds retry support for functions that produce futures with results and context.
Sleeper
A sleeper is used to generate a future that completes after a specified duration.

Type Aliases

DefaultBlockingSleeper
The default implementation of Sleeper when no features are enabled.
DefaultSleeper
The default implementation of Sleeper while feature tokio-sleep enabled.